library(psych)
library(reshape)
library(dplyr)
library(ggplot2)
library(afex)
library(pastecs)
library(car)

df <- read.csv("fitts.csv")
df$A <- factor(df$A)
df$W <- factor(df$W)
#df$Block <- factor(df$Block)

save(df, file = "fitts.RData")

grouped <- group_by(df, Participant)
df.grouped <- summarize(grouped, Throughput = mean(Throughput))

# Visually checking distribution for normality
ggplot(df.grouped, aes(x = Throughput)) + 
  geom_histogram(aes(y = ..density..), binwidth = .5, colour = "black", fill = "#C0C0C0") +
  geom_density(alpha = .2, fill = "#6699FF") +
  theme_bw()

# Q-Q plot - if normal, it should be on a straight line
qplot(sample = df.grouped$Throughput, stat = "qq") + theme_bw()

stat.desc(x = df.grouped$Throughput, basic = FALSE, desc = TRUE, norm = FALSE)
# Shapiro-Wilk test of normality
stat.desc(x = df.grouped$Throughput, basic = FALSE, desc = FALSE, norm = TRUE)

dfM <- filter(df, Condition == "Mouse")
dfS <- filter(df, Condition == "Space")

dir.create("./plots")


plot_distribution <- function(df, condition) {
  for (i in unique(df$Block)) { # could be rewritten with "by" function
    d <- filter(dfM, Block == i)
    
    p <- ggplot(d, aes(x = Throughput)) + 
      geom_histogram(aes(y = ..density..), binwidth = .5, colour = "black", fill = "#C0C0C0") +
      geom_density(alpha = .2, fill = "#6699FF") +
      ggtitle(paste("Group = ", i)) +
      theme_bw(base_size = 20)
    
    plot.name <- sprintf("%s%s%s", "./plots/", i, paste("_", condition, ".pdf"))
    pdf(plot.name)
    print(p)
    dev.off()
  } 
}

print_normality <- function(df, condition) {
  print(paste("Normality tests for ", condition))
  print("=============================")
  for (i in unique(df$Block)) {
    d <- filter(dfM, Block == i)
    
    s <- stat.desc(x = d$Throughput, basic = FALSE, desc = FALSE, norm = TRUE)
    print(paste("Normality tests for Group", i))
    print(round(s, digits = 3))
    print("")
  } 
}

plot_distribution(dfM, "mouse")
plot_distribution(dfS, "space")

print_normality(dfS, "mouse")
print_normality(dfS, "space")

leveneTest(y = dfM$Throughput, group = dfM$Block, center = mean)
leveneTest(y = dfS$Throughput, group = dfS$Block, center = mean)

# Dealing with Outliers 
boxplot(dfM$Throughput ~ dfM$Block)

out <- boxplot(dfM$Throughput ~ dfM$Block, plot = FALSE)$out
print(out)

outParticipants <- dfM$Participant[dfM$Throughput %in% out]
print(outParticipants)

# Remove the outliers from the data
dfMclean <- filter(dfM, !dfM$Participant %in% outParticipants)

# Replace the outlying values
dfM <- dfM %>% mutate(Throughput = replace(Throughput, 
                                           dfM$Throughput %in% out, 
                                           mean(dfM$Throughput) + 2 * sd(dfM$Throughput)))

# ANOVA
fit <- aov_ez(data = dfM,
              id = "Participant",
              dv = "Throughput",
              within = "Block")
print(fit)
summary(fit)

# Post-hoc analysis
posthoc <- lsmeans(fit, "Block", contr = "pairwise")
print(posthoc)

tab <- summary(posthoc$lsmeans)

our.plot <- ggplot(data = tab, aes(x = Block, y = lsmean, fill = Block)) + 
  geom_bar(stat="identity", position = position_dodge()) +
  geom_errorbar(aes(ymin = lower.CL, ymax = upper.CL), 
                width = .3, size = .3, 
                position=position_dodge(0))

our.plot <- our.plot + 
  scale_fill_brewer(palette="Greys") +
  theme_bw(base_size = 20) +
  theme(legend.position = "none") +
  ylab("Throughput (mean)") +
  scale_x_discrete(name = "Blocks", 
                   labels=c("1st", "2nd", "3rd", "4th"))

plotname = "./plots/Throughput_Blocks.pdf"

pdf(plotname)
print(our.plot)
dev.off()

fit <- aov_ez(data = dfM,
              id = "Participant",
              dv = "Throughput",
              within = c("A", "W"))
print(fit)

desc.stats.A <- lsmeans(fit, "A")
desc.stats.W <- lsmeans(fit, "W")

tab <- summary(desc.stats.A)

our.plot <- ggplot(data = tab, aes(x =A, y = lsmean, fill = A)) +
  geom_bar(stat="identity", position = position_dodge()) +
  geom_errorbar(aes(ymin = lower.CL, ymax = upper.CL), 
                width = .3, size = .3, 
                position=position_dodge(0)) +
  scale_fill_brewer(palette="Greys") +
  theme_bw(base_size = 20) +
  theme(legend.position = "none") +
  ylab("Throughput (mean)") +
  scale_x_discrete(name = "Target width", 
                   labels=c("40px", "80px"))

plotName = "./plots/Throughput_A.pdf"
pdf(plotName)
print(our.plot)
dev.off()

desc.stats.Int <- lsmeans(fit, c("W", "A"))
print(desc.stats.Int)
tab <- summary(desc.stats.Int)

our.plot <- ggplot(data = tab, aes(x = W, y = lsmean, fill = A)) +
  geom_bar(stat="identity", position = position_dodge()) +
  geom_errorbar(aes(ymin = lower.CL, ymax = upper.CL), 
                width = .3, size = .3, 
                position=position_dodge(.9)) +
  scale_fill_brewer(palette="Greys", 
                    name="Target Amplitude", 
                    labels = c("150px", "300px")) +
  theme_bw(base_size = 20) +
  ylab("Throughput (mean)") +
  scale_x_discrete(name = "Target width", 
                   labels=c("40px", "80px"))

plotName = "./plots/Throughput_Amplitude.pdf"
pdf(plotName)
print(our.plot)
dev.off()

# Interaction time

fit <- aov_ez(data = dfM,
              id = "Participant",
              dv = "MT",
              within = c("A", "W"))
print(fit)

desc.stats.A <- lsmeans(fit, "A")
desc.stats.W <- lsmeans(fit, "W")

tab <- summary(desc.stats.A)

our.plot <- ggplot(data = tab, aes(x =A, y = lsmean, fill = A)) +
  geom_bar(stat="identity", position = position_dodge()) +
  geom_errorbar(aes(ymin = lower.CL, ymax = upper.CL), 
                width = .3, size = .3, 
                position=position_dodge(0)) +
  scale_fill_brewer(palette="Greys") +
  theme_bw(base_size = 20) +
  theme(legend.position = "none") +
  ylab("MT (mean)") +
  scale_x_discrete(name = "Target width", 
                   labels=c("40px", "80px"))

plotName = "./plots/Throughput_A.pdf"
pdf(plotName)
print(our.plot)
dev.off()

desc.stats.Int <- lsmeans(fit, c("W", "A"))
print(desc.stats.Int)
tab <- summary(desc.stats.Int)

our.plot <- ggplot(data = tab, aes(x = W, y = lsmean, fill = A)) +
  geom_bar(stat="identity", position = position_dodge()) +
  geom_errorbar(aes(ymin = lower.CL, ymax = upper.CL), 
                width = .3, size = .3, 
                position=position_dodge(.9)) +
  scale_fill_brewer(palette="Greys", 
                    name="Target Amplitude", 
                    labels = c("150px", "300px")) +
  theme_bw(base_size = 20) +
  ylab("Throughput (mean)") +
  scale_x_discrete(name = "Target width", 
                   labels=c("40px", "80px"))

plotName = "./plots/Throughput_Amplitude.pdf"
pdf(plotName)
print(our.plot)
dev.off()

# Linear regression
A <- as.numeric(as.character(dfM$A))
W <- as.numeric(as.character(dfM$W))

dfM$logAW <- log2((4 * A) / W)

fit <- lm(MT ~ logAW, data = dfM)
summary(fit)

our.plot <- ggplot(dfM, aes(x=logAW, y=MT)) +
  geom_point(shape=1) + 
  geom_smooth(method = lm) +
  theme_bw(base_size = 20)

plot(fit)

# Multiple linear regression
A <- as.numeric(as.character(df$A))
W <- as.numeric(as.character(df$W))
df$logAW <- log2((4 * A) / W)

fit <- lm(MT ~ logAW * Condition, data = df)
summary(fit)

fit2 <- lm(MT ~ Condition / logAW - 1, data = df)
summary(fit2)

our.plot <- ggplot(df, aes(x=logAW, y=MT, 
                           colour = Condition)) +
  geom_point(shape=1) + 
  geom_smooth(method = lm) +
  theme_bw(base_size = 20) +
  xlab("log2(2D/W)") +
  ylab("Movement Time")

